bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 6. Aventiure
___________________________________________________ #### Aventivre wie gvnther gen isenlande #### nach prvnhilt fvor
###### 325 | ### Itniuowe maere | sich hvoben vber rin ### man sagte daz da waere | manech scoenen magedin ### der gedaht im eine erwerben | gvnther der kvnech gvot ### davon begvnde dem rechen | vil sere hohen der mvot
###### 326 | ### ez was ein kvneginne | gesezen vber se ### ir geliche enheine | man wesse ninder me ### div was vnmazen scoene | vil michel was ir chraft ### si scoz mit snelln degenen | vmb minne den scaft
###### 327 | ### den stein den warf si verre | darnach si witen spranch ### swer ir minne gerte | der mvose ane wanch ### driv spil an gewinnen | der frovwen wol geboren ### gebrast im an dem einem | er hete daz hovbet sin verloren
###### 328 | ### des het div ivnchfrovwe | vnmazen vil getan ### daz gehorte bi dem rine | ein riter wolgetan ### der wande sine sinne | an daz scoene wip ### darvmbe mvosen helede | sit verliesen den lip
###### 329 | ### do sprach der vogt von rine | ich wil nider an den se ### hin ce prvnhilde | swi es mir erge ### ich wil dvrch ir minne | wagen minen lip ### den wil ich verliesen | si ne werde min wip
###### 330 | ### daz wil ich widerraten | sprach do sivrit ### ia hat div kvneginne | so vreisliche sit ### swer vmb ir minne wirbet | daz ez im hohe stat ### des mvget ir der reise | habn waerlichen rat
###### 331 | ### so wil ih iv daz raten | sprach do hagene ### ir bittet sivride | mit iv ce tragene ### di vil starchn swaere | daz ist nv min rat ### sit im daz ist so chvendech | wi ez vm prvenhilde stat
###### 332 | ### er sprach wil dv mir helfen | edel sivrit ### werbn die minnechlichen | tvostv des ich dich bit ### vnt wirt mir ceime trvote | daz minnechliche wip ### ich wil dvrch dinen willen | wagen ere vnde lip
###### 333 | ### des antwurte sivrit | der sigmvndes svn ### gistv mir dine swester | so wil ich ez tvn ### di scoenen chrimhilde | ein kvneginne her ### so ger ich deheines lones | nach minen arbeiten mer
###### 334 | ### daz lob ich sprach do gvnther | sivrit an dine hant ### vnt chvmt div scoene prvenhilt | her in dizze lant ### so wil ich dir ce wibe | mine swester gebn ### so mahtv mit der scoenen | immer vroeliche lebn
###### 335 | ### des swuoren si do eide | di rechen vil her ### des wart ir arbeiten | verre deste mer ### e daz si di frovwen | brahten an den rin ### des mvosen di vil chvenen | sit in grozen sorgen sin
###### 336 | ### sivrit der mvose fveren | di kappen mit im dan ### di der helt vil chvene | mit sorgen gewan ### ab eime getwerge | daz hiez albrich ### sich bereiten zvo der verte | di rechen chven vnd rich
###### 337 | ### also der starche sivrit | di tarnkappen trvoch ### so het er darinne | chrefte genvoch ### wol zwelf manne sterche | zvo sin selbes lip ### er warp mit grozen listen | daz vil herliche wip
###### 338 | ### ovch was div selbe tarnhvot | also getan ### daz darinne worhte | ein ieslicher man ### swaz er selbe wolde | daz in doch niemen sach ### svss gewan er prvenhilde | davon im leide geschach
###### 339 | ### nv sag mir degen sivrit | e daz min vart erge ### daz wir mit wollen ern | chomn an den se ### svlen wir iht rechen fveren | in prvenhilde lant ### drizech tvsent degene | di werdent sciere besant
###### 340 | ### swie vil wir volches fveren | sprach aber sivrit ### ez pfligt div kvneginne | so vreislicher sit ### di mvosen doch ersterben | von ir vbermvot ### ich sol ivch baz bewisen | degen chvene vnd gvot
###### 341 | ### wir svln in rechen wise | ce tal varen den rin ### die wil ich dir benennen | di daz svlen sin ### selbe vierde degene | varn wir an den se ### so erwerbn wir di frovwen | swi ez vns darnach erge
###### 342 | ### der gesellen bin ich einer | daz ander soltv wesn ### der dritte daz si hagene | wir mvgen wol genesen ### der vierde daz si danchwart | der vil chvene man ### vns endvrfen andr tvosent | mit strite nimmer bestan
###### 343 | ### div maere wess ich gerne | sprach der kvnech do ### e daz wir hinnen fveren | des waere ich harte vro ### waz wir chleider solden | vor prvenhilde tragn ### div vns da wol gezaemn | daz svlt ir gvnthere sagn
###### 344 | ### wat die allerbesten | di ieman bevant ### die treit man zallen citen | in prvenhilde lant ### des svlen wir richiv chleider | vor der frovwen tragen ### daz wirs iht haben scande | so man div maere hoere sagen
###### 345 | ### do sprach der degen gvoter | so wil ich selbe gan ### zvo miner lieben mvoter | ob ich erbitten chan ### daz vns ir scoenen meide | helfen prveuen chleit ### di wir tragn mit ern | fver di herlichen meit
###### 346 | ### do sprach von tronege hagne | mit herlichen siten ### waz welt ir iwer mvoter | soelher dienste biten ### lat iwer swester hoeren | wes ir habet mvot ### so wirdet iv ir dienest | zvo dirre hovereise gvot
###### 347 | ### do enbot er siner swester | daz er si wolde sehn ### vnt ovch der degen sivrit | e daz was geschen ### do het sich div scoene | ce wunsche wol gechleit ### daz chomn der vil chvenen | daz waz ir maezliche leit
###### 348 | ### nv was ovch ir gesinde | gezieret als im zam ### di fversten chomn beide | do si daz vernam ### do stvont si von dem sedele | mit zvehten si do gie ### da si den gast vil edele | vnt ovch ir brvoder enpfie
###### 349 | ### willechomn si min brvoder | vnt der geselle sin ### div maere ich wiste gerne | so sprach daz magedin ### waz ir herrn woldet | sit ir ce hove gat ### daz lazet ir mich hoeren | wi ez iv edelen rechen stat
###### 350 | ### do sprach der kvnech gvnther | frovwe ich wilz iv sagn ### wir mvezzen michel sorgen | bi hohem mvote tragn ### wir wellen hoefscen riten | verre in vremdiv lant ### wir solten zvo der reise | haben cierlich gewant
###### 351 | ### nv sizzet lieber brvoder | sprach daz kvneges kint ### vnt lat mich rehte hoeren | wer di frovwen sint ### der ir da gert mit minnen | in ander chvnege lant ### di vzerwelten beide | nam div frovwe bi der hant
###### 352 | ### do gie si mit in beiden | da si e da saz ### vf matrazze div vil richen | ich wil wol wizen daz ### geworht von gvoten bilden | mit golde wol erhabn ### si mohten bi den frovwen | gvote chvrzwile habn
###### 353 | ### friwentliche bliche | vnt gvotlichez sehn ### des mohte da in beiden | harte vil gescehn ### er trvoch si ime hercen | si was im so der lip ### sit wart div scoene chrimhilt | des starchen sivrides wip
###### 354 | ### do sprach der kvnech riche | vil liebiv swester min ### ane dine helfe | chvnd ez niht gesin ### wir wellen chvrzwilen | in prvenhilde lant ### da bedorften wir ce habene | vor frovwen herlich gewant
###### 355 | ### do sprach div ivnchfrovwe | vil lieber brvoder min ### swaz der minen helfe | daran chan gesin ### des bring ich ivch wol innen | daz ich iv bin bereit ### versagt iv ander iemen | daz waere chrimhilde leit
###### 356 | ### ir svlt mich riter edele | niht sorgende biten ### ir svlt mir gebieten | mit herlichen siten ### swaz iv von mir gevalle | des bin ich iv bereit ### vnt tvon ez willechliche | sprach div wunnechlichiv meit
###### 357 | ### wir wellen liebeiv swester | tragn gvot gewant ### daz sol helfen prveuen | iwer edeliv hant ### des volziehen iwer magede | daz ez vns rehte stat ### wand wir der verte | han deheiner slahte rat
###### 358 | ### do sprach div ivnchfrovwe | nv merchent waz ich sage ### ich han selbe siden | nv scaffet daz man trage ### gesteine vns vf den scilden | so wurchen wir div chleit ### des willen was do gvnther | vnt ovch sivrit bereit
###### 359 | ### wer sint die gesellen | sprach div kvnegin ### di mit iv gechleidet | ce hove svlen sin ### er sprach ich selbe vierde | zwene mine man ### danchwart vnt hagene | svln ce hove mit mir gan
###### 360 | ### ir svlt vil rehte merchen | waz ich iv frovwe sage ### daz ich selbe vierde | ce vier tagen trage ### ie drier hande chleider | vnt also gvot gewant ### daz wir ane scande | rvmen prvenhilde lant
###### 361 | ### mit gvotem vrlovbe | di herrn schieden dan ### do hiez ir ivnchfrovwen | drizech meide gan ### vz ir chemnaten | chrimhilt div kvnegin ### di zvo soelhem werche | heten groezlichen sin
###### 362 | ### die arabischen siden | wiz also der sne ### vnt von zazamanch der gvoten | grven alsam der chle ### darin si leiten steine | des wurden gvotiv chleit ### selbe sneit si chrimhilt | div vil herliche meit
###### 363 | ### von vremder vissce hivten | bezoch wolgetan ### ce sehene vremden livten | swaz man der gewan ### die dachten si mit siden | so si se solden tragn ### nv hoeret michel wunder | von der liehten waete sagn
###### 364 | ### von marroch vz dem lande | vnd ovch von lybian ### die allerbestn siden | di ie mer gewan ### deheines kvnegs chvenne | der heten si genvoch ### wol lie daz scinen chrimhilt | daz si in holden willen trvoch
###### 365 | ### sit si der hohen verte | heten nv gegert ### haermine vedern | di dvhten si vnwert ### pfellel darob lagen | swarz alsam ein chol ### daz noch snellen heleden | stvende in hohgeciten wol
###### 366 | ### vz arabischem golde | vil gesteins scein ### der frovwen vnmvoze | div ne was niht chlein ### inre siben wochen | bereiten si div chleit ### do was ovch ir gewaefen | den gvoten rechen bereit
###### 367 | ### do si bereitet warn | do was in vf den rin ### gemachet flizechlichen | ein starchez sciffelin ### daz si tragen solde | vol nider an den se ### den edelen ivnchfrovwon | was von arbeiten we
###### 368 | ### do sagte man den rechen | in waeren nv bereit ### div si da fveren solden | ir zierlichen chleit ### also di da gerten | daz was nv getan ### do ne wolden si niht langer | bi dem rine bestan
###### 369 | ### nach den hergesellen | wart ein bote gesant ### ob si wolden scovwen | niwez ir gewant ### ob ez den helden waere | ce chvrz vnd ovch ze lanch ### ez was in rehter maze | des sagten si den frovwen danch
###### 370 | ### fver alle di si chomn | di mvosen in des iehn ### daz si cer werlde heten | bezers niht gesehn ### des mohten si se gerne | da ze hove tragn ### von bezer rechen waete | chvnde niemn niht gesagn
###### 371 | ### vil groezliche danchen | wart do niht verdeit ### do gerten vrlovbes | di helde vil gemeit ### in riterlichen zvhten | di herrn taten daz ### des wurden liehtiv ovgen | von wein trveb vnde naz
###### 372 | ### si sprach vil lieber brvoder | ir moehtet noh bestan ### vnt werbet ander frovwen | daz hiez ich wol getan ### da iv so sere enwage | stvende niht der lip ### ir mvgt hie naher vinden | ein also hochgeborn wip
###### 373 | ### ich waen in sagt ir herce | daz in davon geschach ### si weinten al geliche | swaz iemn gesprach ### ir golt in vor den brvesten | wart von trahen sal ### di vielen in genote | von den ovgen hin ce tal
###### 374 | ### si sprach herre sivrit | lat iv bevolhen sin ### vf triwe vnt vf genade | den lieben brvoder min ### daz im iht gewerre | in prvnhilde lant ### daz lobte der vil chvene | in frovn chrimhilde hant
###### 375 | ### do sprach der degen riche | ob mir min lebn bestat ### so svlt ir aller sorgen | frovwe habn rat ### ich bringen iv gesvnden | her wider an den rin ### daz wizet sicherlichen | im neich daz scoene magedin
###### 376 | ### er goltvarwen scilde | man trvog in vf den sant ### vnt braht in zvo zin | allez ir gewant ### ir ross hiez man in ciehen | si wolden riten dan ### da wart von scoenen frovwen | vil michel weinen getan
###### 377 | ### do stvonden in den venstern | div minnechlichen chint ### ir sciff mit dem segele | daz rvort ein hoher wint ### di stolzen hergeselln | di sazen vf den rin ### do sprach der kvnech gvnther | wer sol nv sciffmeister sin
###### 378 | ### daz wil ich sprach sivrit | ich chan ivch vf der flvot ### hinnen wol gefveren | daz wizzet helde gvot ### di rehten wazerstrazen | di sint mir wol bechant ### si scieden vroelichen | vz der bvrgonden lant
###### 379 | ### sivrit do balde | eine scalten gewan ### von stade begvnde schieben | der chreftige man ### gvnther der chvene | ein rvoder selbe nam ### do hvoben sich von lande | di snellen riter lobesam
###### 380 | ### si fvorten riche spise | darzvo vil gvoten win ### den besten den man chvnde | vinden vmben rin ### ir rosse div stvonden scone | si heten gvot gemach ### ir sciff daz gie vil ebene | vil lvzel leides in gescach
###### 381 | ### ir vil starchen segelseil | div wurden in gestraht ### si fvoren zweinzech mile | e daz ez wurde naht ### mit eime gvotem winde | nider gegn dem se ### ir starchez arbeiten | tet sit den hohgemvoten we
###### 382 | ### an dem zwelften morgen | so wir hoeren sagen ### heten si di winde | verre dan getragen ### gegen isensteine | in prvnhilde lant ### daz was ir deheinem | niwan sivride erchant
###### 383 | ### do der kvnec gvnther | so vil der bvrge sach ### vnt ovch di witen marche | wie balde er do sprach ### sagt mir friwent sivrit | ist iv daz bechant ### wes sint dise bvrge | vnt ovch daz herliche lant
###### 384 | ### des antwurte sivrit | ez ist mir wol bechant ### ez ist prvnhilde | livte vnde lant ### vnt isenstein div veste | als ir mich hortet iehn ### da mvget ir noch hivte | vil scoener frovwen gesehn
###### 385 | ### vnt wil iv helden raten | ir habt einen mvot ### ir ieht geliche | ia dvnchent ez mich gvot ### swenne wir noch hivte | fvr prvnhilde gan ### so mvezen wir mit sorgen | vor der chvneginne stan
###### 386 | ### do wir di minnechlichen | bi ir gesinde sehn ### so svlt ir helde maere | wan einer rede iehn ### gvnther si min herre | vnt ich si sin man ### des er da hat gedingen | daz wirt allez getan
###### 387 | ### des waren si bereite | swaz er si loben hiez ### dvrh ir vbermvete ir | deheiner ez niht liez ### si iahen swes er wolde | davon in wol gescach ### do der kvnech gvnther | di scoenen prvnhilde sach
###### 388 | ### ia ne lob ihz niht so verre | dvrch die liebe din ### so dvrch dine swester | daz scoene magedin ### div ist mir sam min sele | vnt so min selbes lip ### ich wil daz gerne dienen | daz si werde min wip

<<< Übersicht <<< vorige Seite nächste Seite >>>